summaryrefslogtreecommitdiffstats
path: root/chrome/browser
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser')
-rw-r--r--chrome/browser/chromeos/login/login_display_host_impl.cc2
-rw-r--r--chrome/browser/chromeos/login/login_display_host_impl.h2
-rw-r--r--chrome/browser/chromeos/login/webui_screen_locker.cc2
-rw-r--r--chrome/browser/chromeos/login/webui_screen_locker.h2
-rw-r--r--chrome/browser/chromeos/ui/app_launch_view.cc2
-rw-r--r--chrome/browser/chromeos/ui/app_launch_view.h2
-rw-r--r--chrome/browser/extensions/api/identity/web_auth_flow.cc2
-rw-r--r--chrome/browser/extensions/api/identity/web_auth_flow.h2
-rw-r--r--chrome/browser/extensions/extension_host.cc2
-rw-r--r--chrome/browser/extensions/extension_host.h2
-rw-r--r--chrome/browser/infobars/infobar_service.cc2
-rw-r--r--chrome/browser/infobars/infobar_service.h2
-rw-r--r--chrome/browser/notifications/balloon_host.cc2
-rw-r--r--chrome/browser/notifications/balloon_host.h2
-rw-r--r--chrome/browser/page_cycler/page_cycler_unittest.cc2
-rw-r--r--chrome/browser/prerender/prerender_browsertest.cc4
-rw-r--r--chrome/browser/prerender/prerender_contents.cc2
-rw-r--r--chrome/browser/prerender/prerender_contents.h2
-rw-r--r--chrome/browser/printing/print_view_manager.cc2
-rw-r--r--chrome/browser/printing/print_view_manager.h2
-rw-r--r--chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc4
-rw-r--r--chrome/browser/tab_contents/background_contents.cc2
-rw-r--r--chrome/browser/tab_contents/background_contents.h2
-rw-r--r--chrome/browser/ui/cocoa/hung_renderer_controller.h2
-rw-r--r--chrome/browser/ui/cocoa/hung_renderer_controller.mm8
-rw-r--r--chrome/browser/ui/gtk/hung_renderer_dialog_gtk.cc2
-rw-r--r--chrome/browser/ui/panels/panel_host.cc2
-rw-r--r--chrome/browser/ui/panels/panel_host.h2
-rw-r--r--chrome/browser/ui/sad_tab_helper.cc2
-rw-r--r--chrome/browser/ui/sad_tab_helper.h2
-rw-r--r--chrome/browser/ui/search/instant_controller.cc2
-rw-r--r--chrome/browser/ui/search/instant_controller.h4
-rw-r--r--chrome/browser/ui/search/instant_extended_interactive_uitest.cc4
-rw-r--r--chrome/browser/ui/search/instant_ntp.cc4
-rw-r--r--chrome/browser/ui/search/instant_ntp.h2
-rw-r--r--chrome/browser/ui/search/instant_page.h4
-rw-r--r--chrome/browser/ui/search/instant_page_unittest.cc2
-rw-r--r--chrome/browser/ui/views/hung_renderer_view.cc2
-rw-r--r--chrome/browser/ui/views/hung_renderer_view.h2
39 files changed, 48 insertions, 48 deletions
diff --git a/chrome/browser/chromeos/login/login_display_host_impl.cc b/chrome/browser/chromeos/login/login_display_host_impl.cc
index 904a19b..47c539f 100644
--- a/chrome/browser/chromeos/login/login_display_host_impl.cc
+++ b/chrome/browser/chromeos/login/login_display_host_impl.cc
@@ -603,7 +603,7 @@ void LoginDisplayHostImpl::Observe(
////////////////////////////////////////////////////////////////////////////////
// LoginDisplayHostImpl, WebContentsObserver implementation:
-void LoginDisplayHostImpl::RenderViewGone(base::TerminationStatus status) {
+void LoginDisplayHostImpl::RenderProcessGone(base::TerminationStatus status) {
// Do not try to restore on shutdown
if (browser_shutdown::GetShutdownType() != browser_shutdown::NOT_VALID)
return;
diff --git a/chrome/browser/chromeos/login/login_display_host_impl.h b/chrome/browser/chromeos/login/login_display_host_impl.h
index 42c279e..481001c 100644
--- a/chrome/browser/chromeos/login/login_display_host_impl.h
+++ b/chrome/browser/chromeos/login/login_display_host_impl.h
@@ -91,7 +91,7 @@ class LoginDisplayHostImpl : public LoginDisplayHost,
const content::NotificationDetails& details) OVERRIDE;
// Overridden from content::WebContentsObserver:
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
private:
// Marks display host for deletion.
diff --git a/chrome/browser/chromeos/login/webui_screen_locker.cc b/chrome/browser/chromeos/login/webui_screen_locker.cc
index b7ac13e..58baa1e 100644
--- a/chrome/browser/chromeos/login/webui_screen_locker.cc
+++ b/chrome/browser/chromeos/login/webui_screen_locker.cc
@@ -319,7 +319,7 @@ void WebUIScreenLocker::SystemResumed(const base::TimeDelta& sleep_duration) {
base::Bind(&WebUIScreenLocker::FocusUserPod, weak_factory_.GetWeakPtr()));
}
-void WebUIScreenLocker::RenderViewGone(base::TerminationStatus status) {
+void WebUIScreenLocker::RenderProcessGone(base::TerminationStatus status) {
if (browser_shutdown::GetShutdownType() == browser_shutdown::NOT_VALID &&
status != base::TERMINATION_STATUS_NORMAL_TERMINATION) {
LOG(ERROR) << "Renderer crash on lock screen";
diff --git a/chrome/browser/chromeos/login/webui_screen_locker.h b/chrome/browser/chromeos/login/webui_screen_locker.h
index 8c52c81..4da5d304 100644
--- a/chrome/browser/chromeos/login/webui_screen_locker.h
+++ b/chrome/browser/chromeos/login/webui_screen_locker.h
@@ -107,7 +107,7 @@ class WebUIScreenLocker : public WebUILoginView,
const base::TimeTicks& time) OVERRIDE;
// Overridden from content::WebContentsObserver:
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
private:
friend class test::WebUIScreenLockerTester;
diff --git a/chrome/browser/chromeos/ui/app_launch_view.cc b/chrome/browser/chromeos/ui/app_launch_view.cc
index 9975b1c..3ea698d 100644
--- a/chrome/browser/chromeos/ui/app_launch_view.cc
+++ b/chrome/browser/chromeos/ui/app_launch_view.cc
@@ -98,7 +98,7 @@ views::View* AppLaunchView::GetContentsView() {
////////////////////////////////////////////////////////////////////////////////
// AppLaunchView, content::WebContentsObserver implementation.
-void AppLaunchView::RenderViewGone(
+void AppLaunchView::RenderProcessGone(
base::TerminationStatus status) {
LOG(ERROR) << "Splash screen terminated with status " << status;
AppLaunchView::CloseAppLaunchSplashScreen();
diff --git a/chrome/browser/chromeos/ui/app_launch_view.h b/chrome/browser/chromeos/ui/app_launch_view.h
index 5ac78eb..838fd7e 100644
--- a/chrome/browser/chromeos/ui/app_launch_view.h
+++ b/chrome/browser/chromeos/ui/app_launch_view.h
@@ -54,7 +54,7 @@ class AppLaunchView : public views::WidgetDelegateView,
virtual views::View* GetContentsView() OVERRIDE;
// content::WebContentsObserver overrides.
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
void Show();
void Close();
diff --git a/chrome/browser/extensions/api/identity/web_auth_flow.cc b/chrome/browser/extensions/api/identity/web_auth_flow.cc
index 2986b16..fa2e3cf 100644
--- a/chrome/browser/extensions/api/identity/web_auth_flow.cc
+++ b/chrome/browser/extensions/api/identity/web_auth_flow.cc
@@ -207,7 +207,7 @@ void WebAuthFlow::Observe(int type,
}
}
-void WebAuthFlow::RenderViewGone(base::TerminationStatus status) {
+void WebAuthFlow::RenderProcessGone(base::TerminationStatus status) {
if (delegate_)
delegate_->OnAuthFlowFailure(WebAuthFlow::WINDOW_CLOSED);
}
diff --git a/chrome/browser/extensions/api/identity/web_auth_flow.h b/chrome/browser/extensions/api/identity/web_auth_flow.h
index a3764ec..077b1f0 100644
--- a/chrome/browser/extensions/api/identity/web_auth_flow.h
+++ b/chrome/browser/extensions/api/identity/web_auth_flow.h
@@ -108,7 +108,7 @@ class WebAuthFlow : public content::NotificationObserver,
virtual void DidNavigateMainFrame(
const content::LoadCommittedDetails& details,
const content::FrameNavigateParams& params) OVERRIDE;
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
virtual void DidStartProvisionalLoadForFrame(
int64 frame_id,
int64 parent_frame_id,
diff --git a/chrome/browser/extensions/extension_host.cc b/chrome/browser/extensions/extension_host.cc
index 5668535..38d559c 100644
--- a/chrome/browser/extensions/extension_host.cc
+++ b/chrome/browser/extensions/extension_host.cc
@@ -324,7 +324,7 @@ void ExtensionHost::ResizeDueToAutoResize(WebContents* source,
view()->ResizeDueToAutoResize(new_size);
}
-void ExtensionHost::RenderViewGone(base::TerminationStatus status) {
+void ExtensionHost::RenderProcessGone(base::TerminationStatus status) {
// During browser shutdown, we may use sudden termination on an extension
// process, so it is expected to lose our connection to the render view.
// Do nothing.
diff --git a/chrome/browser/extensions/extension_host.h b/chrome/browser/extensions/extension_host.h
index b9a99723..f4e8886 100644
--- a/chrome/browser/extensions/extension_host.h
+++ b/chrome/browser/extensions/extension_host.h
@@ -143,7 +143,7 @@ class ExtensionHost : public content::WebContentsDelegate,
virtual void RenderViewDeleted(
content::RenderViewHost* render_view_host) OVERRIDE;
virtual void RenderViewReady() OVERRIDE;
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
virtual void DocumentAvailableInMainFrame() OVERRIDE;
virtual void DidStopLoading(
content::RenderViewHost* render_view_host) OVERRIDE;
diff --git a/chrome/browser/infobars/infobar_service.cc b/chrome/browser/infobars/infobar_service.cc
index 34f99e6..90915ef 100644
--- a/chrome/browser/infobars/infobar_service.cc
+++ b/chrome/browser/infobars/infobar_service.cc
@@ -107,7 +107,7 @@ InfoBarService::~InfoBarService() {
RemoveAllInfoBars(false);
}
-void InfoBarService::RenderViewGone(base::TerminationStatus status) {
+void InfoBarService::RenderProcessGone(base::TerminationStatus status) {
RemoveAllInfoBars(true);
}
diff --git a/chrome/browser/infobars/infobar_service.h b/chrome/browser/infobars/infobar_service.h
index 5ea6ce0..e0f40aa 100644
--- a/chrome/browser/infobars/infobar_service.h
+++ b/chrome/browser/infobars/infobar_service.h
@@ -78,7 +78,7 @@ class InfoBarService : public content::WebContentsObserver,
virtual ~InfoBarService();
// content::WebContentsObserver:
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
// content::NotificationObserver:
diff --git a/chrome/browser/notifications/balloon_host.cc b/chrome/browser/notifications/balloon_host.cc
index 24c39f2..5ee2ce6 100644
--- a/chrome/browser/notifications/balloon_host.cc
+++ b/chrome/browser/notifications/balloon_host.cc
@@ -116,7 +116,7 @@ void BalloonHost::RenderViewReady() {
content::NotificationService::NoDetails());
}
-void BalloonHost::RenderViewGone(base::TerminationStatus status) {
+void BalloonHost::RenderProcessGone(base::TerminationStatus status) {
CloseContents(web_contents_.get());
}
diff --git a/chrome/browser/notifications/balloon_host.h b/chrome/browser/notifications/balloon_host.h
index 83dc9cc..693b21b 100644
--- a/chrome/browser/notifications/balloon_host.h
+++ b/chrome/browser/notifications/balloon_host.h
@@ -74,7 +74,7 @@ class BalloonHost : public content::WebContentsDelegate,
virtual void RenderViewCreated(
content::RenderViewHost* render_view_host) OVERRIDE;
virtual void RenderViewReady() OVERRIDE;
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
// Message handlers
diff --git a/chrome/browser/page_cycler/page_cycler_unittest.cc b/chrome/browser/page_cycler/page_cycler_unittest.cc
index 0f0e3ac..f46bf09 100644
--- a/chrome/browser/page_cycler/page_cycler_unittest.cc
+++ b/chrome/browser/page_cycler/page_cycler_unittest.cc
@@ -65,7 +65,7 @@ class MockPageCycler : public PageCycler {
int error_code,
const string16& error_description,
RenderViewHost* render_view_host));
- MOCK_METHOD1(RenderViewGone, void(base::TerminationStatus status));
+ MOCK_METHOD1(RenderProcessGone, void(base::TerminationStatus status));
void PageCyclerDidFailProvisionalLoad(
int64 frame_id,
diff --git a/chrome/browser/prerender/prerender_browsertest.cc b/chrome/browser/prerender/prerender_browsertest.cc
index 47117f1..d3af6ef 100644
--- a/chrome/browser/prerender/prerender_browsertest.cc
+++ b/chrome/browser/prerender/prerender_browsertest.cc
@@ -271,7 +271,7 @@ class TestPrerenderContents : public PrerenderContents {
}
}
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE {
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE {
// On quit, it's possible to end up here when render processes are closed
// before the PrerenderManager is destroyed. As a result, it's possible to
// get either FINAL_STATUS_APP_TERMINATING or FINAL_STATUS_RENDERER_CRASHED
@@ -285,7 +285,7 @@ class TestPrerenderContents : public PrerenderContents {
expected_final_status_ = FINAL_STATUS_RENDERER_CRASHED;
}
- PrerenderContents::RenderViewGone(status);
+ PrerenderContents::RenderProcessGone(status);
}
virtual bool AddAliasURL(const GURL& url) OVERRIDE {
diff --git a/chrome/browser/prerender/prerender_contents.cc b/chrome/browser/prerender/prerender_contents.cc
index de1ec58..cf26921 100644
--- a/chrome/browser/prerender/prerender_contents.cc
+++ b/chrome/browser/prerender/prerender_contents.cc
@@ -559,7 +559,7 @@ bool PrerenderContents::Matches(
std::bind2nd(std::equal_to<GURL>(), url)) != 0;
}
-void PrerenderContents::RenderViewGone(base::TerminationStatus status) {
+void PrerenderContents::RenderProcessGone(base::TerminationStatus status) {
Destroy(FINAL_STATUS_RENDERER_CRASHED);
}
diff --git a/chrome/browser/prerender/prerender_contents.h b/chrome/browser/prerender/prerender_contents.h
index fca0c8f..a3030f9 100644
--- a/chrome/browser/prerender/prerender_contents.h
+++ b/chrome/browser/prerender/prerender_contents.h
@@ -231,7 +231,7 @@ class PrerenderContents : public content::NotificationObserver,
virtual void DidUpdateFaviconURL(int32 page_id,
const std::vector<content::FaviconURL>& urls) OVERRIDE;
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
// content::NotificationObserver
virtual void Observe(int type,
diff --git a/chrome/browser/printing/print_view_manager.cc b/chrome/browser/printing/print_view_manager.cc
index 17666df..69bce10 100644
--- a/chrome/browser/printing/print_view_manager.cc
+++ b/chrome/browser/printing/print_view_manager.cc
@@ -184,7 +184,7 @@ void PrintViewManager::StopNavigation() {
TerminatePrintJob(true);
}
-void PrintViewManager::RenderViewGone(base::TerminationStatus status) {
+void PrintViewManager::RenderProcessGone(base::TerminationStatus status) {
print_preview_state_ = NOT_PREVIEWING;
ReleasePrinterQuery();
diff --git a/chrome/browser/printing/print_view_manager.h b/chrome/browser/printing/print_view_manager.h
index de950db..55b4708 100644
--- a/chrome/browser/printing/print_view_manager.h
+++ b/chrome/browser/printing/print_view_manager.h
@@ -93,7 +93,7 @@ class PrintViewManager : public content::NotificationObserver,
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
// Terminates or cancels the print job if one was pending.
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
// Cancels the print job.
virtual void StopNavigation() OVERRIDE;
diff --git a/chrome/browser/tab_contents/background_contents.cc b/chrome/browser/tab_contents/background_contents.cc
index 106351c..f37e1b8 100644
--- a/chrome/browser/tab_contents/background_contents.cc
+++ b/chrome/browser/tab_contents/background_contents.cc
@@ -110,7 +110,7 @@ void BackgroundContents::AddNewContents(WebContents* source,
new_contents, disposition, initial_pos, user_gesture, was_blocked);
}
-void BackgroundContents::RenderViewGone(base::TerminationStatus status) {
+void BackgroundContents::RenderProcessGone(base::TerminationStatus status) {
content::NotificationService::current()->Notify(
chrome::NOTIFICATION_BACKGROUND_CONTENTS_TERMINATED,
content::Source<Profile>(profile_),
diff --git a/chrome/browser/tab_contents/background_contents.h b/chrome/browser/tab_contents/background_contents.h
index be2c71f..e6b817c 100644
--- a/chrome/browser/tab_contents/background_contents.h
+++ b/chrome/browser/tab_contents/background_contents.h
@@ -63,7 +63,7 @@ class BackgroundContents : public content::WebContentsDelegate,
bool* was_blocked) OVERRIDE;
// content::WebContentsObserver implementation:
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
// content::NotificationObserver
virtual void Observe(int type,
diff --git a/chrome/browser/ui/cocoa/hung_renderer_controller.h b/chrome/browser/ui/cocoa/hung_renderer_controller.h
index 1725726..282f218 100644
--- a/chrome/browser/ui/cocoa/hung_renderer_controller.h
+++ b/chrome/browser/ui/cocoa/hung_renderer_controller.h
@@ -73,7 +73,7 @@ class WebContents;
// Called by |hungContentsObserver_| to indicate that |hungContents_|
// has gone away.
-- (void)renderViewGone;
+- (void)renderProcessGone;
@end // HungRendererController
diff --git a/chrome/browser/ui/cocoa/hung_renderer_controller.mm b/chrome/browser/ui/cocoa/hung_renderer_controller.mm
index b75da41..dc21d44 100644
--- a/chrome/browser/ui/cocoa/hung_renderer_controller.mm
+++ b/chrome/browser/ui/cocoa/hung_renderer_controller.mm
@@ -49,11 +49,11 @@ class WebContentsObserverBridge : public content::WebContentsObserver {
protected:
// WebContentsObserver overrides:
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE {
- [controller_ renderViewGone];
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE {
+ [controller_ renderProcessGone];
}
virtual void WebContentsDestroyed(WebContents* tab) OVERRIDE {
- [controller_ renderViewGone];
+ [controller_ renderProcessGone];
}
private:
@@ -205,7 +205,7 @@ class WebContentsObserverBridge : public content::WebContentsObserver {
}
}
-- (void)renderViewGone {
+- (void)renderProcessGone {
// Cannot call performClose:, because the close button is disabled.
[self close];
}
diff --git a/chrome/browser/ui/gtk/hung_renderer_dialog_gtk.cc b/chrome/browser/ui/gtk/hung_renderer_dialog_gtk.cc
index bf703d6..c0ea1ac 100644
--- a/chrome/browser/ui/gtk/hung_renderer_dialog_gtk.cc
+++ b/chrome/browser/ui/gtk/hung_renderer_dialog_gtk.cc
@@ -52,7 +52,7 @@ class HungRendererDialogGtk {
}
// content::WebContentsObserver overrides:
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE {
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE {
dialog_->Hide();
}
virtual void WebContentsDestroyed(WebContents* tab) OVERRIDE {
diff --git a/chrome/browser/ui/panels/panel_host.cc b/chrome/browser/ui/panels/panel_host.cc
index 60658da..d40c5a4c 100644
--- a/chrome/browser/ui/panels/panel_host.cc
+++ b/chrome/browser/ui/panels/panel_host.cc
@@ -201,7 +201,7 @@ void PanelHost::RenderViewCreated(content::RenderViewHost* render_view_host) {
render_view_host->GetRoutingID(), window->GetWindowId()));
}
-void PanelHost::RenderViewGone(base::TerminationStatus status) {
+void PanelHost::RenderProcessGone(base::TerminationStatus status) {
CloseContents(web_contents_.get());
}
diff --git a/chrome/browser/ui/panels/panel_host.h b/chrome/browser/ui/panels/panel_host.h
index e7344cf..3c94c0f 100644
--- a/chrome/browser/ui/panels/panel_host.h
+++ b/chrome/browser/ui/panels/panel_host.h
@@ -78,7 +78,7 @@ class PanelHost : public content::WebContentsDelegate,
// content::WebContentsObserver overrides.
virtual void RenderViewCreated(
content::RenderViewHost* render_view_host) OVERRIDE;
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
virtual void WebContentsDestroyed(
content::WebContents* web_contents) OVERRIDE;
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
diff --git a/chrome/browser/ui/sad_tab_helper.cc b/chrome/browser/ui/sad_tab_helper.cc
index 9d834a6..dfcb1cf 100644
--- a/chrome/browser/ui/sad_tab_helper.cc
+++ b/chrome/browser/ui/sad_tab_helper.cc
@@ -23,7 +23,7 @@ SadTabHelper::SadTabHelper(content::WebContents* web_contents)
content::Source<content::WebContents>(web_contents));
}
-void SadTabHelper::RenderViewGone(base::TerminationStatus status) {
+void SadTabHelper::RenderProcessGone(base::TerminationStatus status) {
// Only show the sad tab if we're not in browser shutdown, so that WebContents
// objects that are not in a browser (e.g., HTML dialogs) and thus are
// visible do not flash a sad tab page.
diff --git a/chrome/browser/ui/sad_tab_helper.h b/chrome/browser/ui/sad_tab_helper.h
index e375e8b..0ea35d0 100644
--- a/chrome/browser/ui/sad_tab_helper.h
+++ b/chrome/browser/ui/sad_tab_helper.h
@@ -34,7 +34,7 @@ class SadTabHelper : public content::WebContentsObserver,
void InstallSadTab(base::TerminationStatus status);
// Overridden from content::WebContentsObserver:
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
// Overridden from content::NotificationObserver:
virtual void Observe(int type,
diff --git a/chrome/browser/ui/search/instant_controller.cc b/chrome/browser/ui/search/instant_controller.cc
index 6b40b04..55bb21f 100644
--- a/chrome/browser/ui/search/instant_controller.cc
+++ b/chrome/browser/ui/search/instant_controller.cc
@@ -449,7 +449,7 @@ void InstantController::InstantSupportDetermined(
}
}
-void InstantController::InstantPageRenderViewGone(
+void InstantController::InstantPageRenderProcessGone(
const content::WebContents* contents) {
if (IsContentsFrom(ntp(), contents)) {
DeletePageSoon(ntp_.Pass());
diff --git a/chrome/browser/ui/search/instant_controller.h b/chrome/browser/ui/search/instant_controller.h
index 721c3b3..7964d87 100644
--- a/chrome/browser/ui/search/instant_controller.h
+++ b/chrome/browser/ui/search/instant_controller.h
@@ -167,7 +167,7 @@ class InstantController : public InstantPage::Delegate,
FRIEND_TEST_ALL_PREFIXES(InstantExtendedTest, PreloadedNTPIsUsedInNewTab);
FRIEND_TEST_ALL_PREFIXES(InstantExtendedTest, PreloadedNTPIsUsedInSameTab);
FRIEND_TEST_ALL_PREFIXES(InstantExtendedTest, PreloadedNTPForWrongProvider);
- FRIEND_TEST_ALL_PREFIXES(InstantExtendedTest, PreloadedNTPRenderViewGone);
+ FRIEND_TEST_ALL_PREFIXES(InstantExtendedTest, PreloadedNTPRenderProcessGone);
FRIEND_TEST_ALL_PREFIXES(InstantExtendedTest,
PreloadedNTPDoesntSupportInstant);
FRIEND_TEST_ALL_PREFIXES(InstantExtendedTest, ProcessIsolation);
@@ -200,7 +200,7 @@ class InstantController : public InstantPage::Delegate,
virtual void InstantSupportDetermined(
const content::WebContents* contents,
bool supports_instant) OVERRIDE;
- virtual void InstantPageRenderViewGone(
+ virtual void InstantPageRenderProcessGone(
const content::WebContents* contents) OVERRIDE;
virtual void InstantPageAboutToNavigateMainFrame(
const content::WebContents* contents,
diff --git a/chrome/browser/ui/search/instant_extended_interactive_uitest.cc b/chrome/browser/ui/search/instant_extended_interactive_uitest.cc
index 344b7e4..3aa6851 100644
--- a/chrome/browser/ui/search/instant_extended_interactive_uitest.cc
+++ b/chrome/browser/ui/search/instant_extended_interactive_uitest.cc
@@ -457,7 +457,7 @@ IN_PROC_BROWSER_TEST_F(InstantExtendedTest, PreloadedNTPForWrongProvider) {
EXPECT_NE(ntp_url, active_tab->GetURL());
}
-IN_PROC_BROWSER_TEST_F(InstantExtendedTest, PreloadedNTPRenderViewGone) {
+IN_PROC_BROWSER_TEST_F(InstantExtendedTest, PreloadedNTPRenderProcessGone) {
// Setup Instant.
ASSERT_NO_FATAL_FAILURE(SetupInstant(browser()));
FocusOmniboxAndWaitForInstantNTPSupport();
@@ -467,7 +467,7 @@ IN_PROC_BROWSER_TEST_F(InstantExtendedTest, PreloadedNTPRenderViewGone) {
EXPECT_FALSE(instant()->ntp()->IsLocal());
// NTP not reloaded after being killed.
- instant()->InstantPageRenderViewGone(instant()->ntp()->contents());
+ instant()->InstantPageRenderProcessGone(instant()->ntp()->contents());
EXPECT_EQ(NULL, instant()->ntp());
// Open new tab. Should use local NTP.
diff --git a/chrome/browser/ui/search/instant_ntp.cc b/chrome/browser/ui/search/instant_ntp.cc
index 23fad12..e02b659 100644
--- a/chrome/browser/ui/search/instant_ntp.cc
+++ b/chrome/browser/ui/search/instant_ntp.cc
@@ -104,8 +104,8 @@ void InstantNTP::RenderViewCreated(content::RenderViewHost* render_view_host) {
delegate()->InstantPageRenderViewCreated(contents());
}
-void InstantNTP::RenderViewGone(base::TerminationStatus /* status */) {
- delegate()->InstantPageRenderViewGone(contents());
+void InstantNTP::RenderProcessGone(base::TerminationStatus /* status */) {
+ delegate()->InstantPageRenderProcessGone(contents());
}
// static
diff --git a/chrome/browser/ui/search/instant_ntp.h b/chrome/browser/ui/search/instant_ntp.h
index 510fe08..d9382f5 100644
--- a/chrome/browser/ui/search/instant_ntp.h
+++ b/chrome/browser/ui/search/instant_ntp.h
@@ -52,7 +52,7 @@ class InstantNTP : public InstantPage,
// Overridden from content::WebContentsObserver:
virtual void RenderViewCreated(
content::RenderViewHost* render_view_host) OVERRIDE;
- virtual void RenderViewGone(
+ virtual void RenderProcessGone(
base::TerminationStatus status) OVERRIDE;
// Overriden from InstantLoader::Delegate:
diff --git a/chrome/browser/ui/search/instant_page_unittest.cc b/chrome/browser/ui/search/instant_page_unittest.cc
index c751cfe..effa9c6 100644
--- a/chrome/browser/ui/search/instant_page_unittest.cc
+++ b/chrome/browser/ui/search/instant_page_unittest.cc
@@ -32,7 +32,7 @@ class FakePageDelegate : public InstantPage::Delegate {
MOCK_METHOD2(InstantSupportDetermined,
void(const content::WebContents* contents,
bool supports_instant));
- MOCK_METHOD1(InstantPageRenderViewGone,
+ MOCK_METHOD1(InstantPageRenderProcessGone,
void(const content::WebContents* contents));
MOCK_METHOD2(InstantPageAboutToNavigateMainFrame,
void(const content::WebContents* contents,
diff --git a/chrome/browser/ui/views/hung_renderer_view.cc b/chrome/browser/ui/views/hung_renderer_view.cc
index 5ff6306..665064b 100644
--- a/chrome/browser/ui/views/hung_renderer_view.cc
+++ b/chrome/browser/ui/views/hung_renderer_view.cc
@@ -158,7 +158,7 @@ HungPagesTableModel::WebContentsObserverImpl::WebContentsObserverImpl(
model_(model) {
}
-void HungPagesTableModel::WebContentsObserverImpl::RenderViewGone(
+void HungPagesTableModel::WebContentsObserverImpl::RenderProcessGone(
base::TerminationStatus status) {
model_->TabDestroyed(this);
}
diff --git a/chrome/browser/ui/views/hung_renderer_view.h b/chrome/browser/ui/views/hung_renderer_view.h
index a657b44..0593f1f 100644
--- a/chrome/browser/ui/views/hung_renderer_view.h
+++ b/chrome/browser/ui/views/hung_renderer_view.h
@@ -74,7 +74,7 @@ class HungPagesTableModel : public ui::TableModel, public views::TableGrouper {
}
// WebContentsObserver overrides:
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE;
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE;
virtual void WebContentsDestroyed(content::WebContents* tab) OVERRIDE;
private:
diff --git a/chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc b/chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc
index cdc9e9ee..a388d97 100644
--- a/chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc
+++ b/chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc
@@ -357,7 +357,7 @@ IN_PROC_BROWSER_TEST_F(ChromeRenderProcessHostTest,
}
// This class's goal is to close the browser window when a renderer process has
// crashed. It does so by monitoring WebContents for RenderViewGone event and
// closing the passed in TabStripModel. This is used in the following test case.
class WindowDestroyer : public content::WebContentsObserver {
public:
@@ -366,7 +366,7 @@ class WindowDestroyer : public content::WebContentsObserver {
tab_strip_model_(model) {
}
- virtual void RenderViewGone(base::TerminationStatus status) OVERRIDE {
+ virtual void RenderProcessGone(base::TerminationStatus status) OVERRIDE {
// Wait for the window to be destroyed, which will ensure all other
// RenderViewHost objects are deleted before we return and proceed with
// the next iteration of notifications.
@@ -357,7 +357,7 @@ IN_PROC_BROWSER_TEST_F(ChromeRenderProcessHostTest,
}
// This class's goal is to close the browser window when a renderer process has
-// crashed. It does so by monitoring WebContents for RenderViewGone event and
+// crashed. It does so by monitoring WebContents for RenderProcessGone event and
// closing the passed in TabStripModel. This is used in the following test case.
class WindowDestroyer : public content::WebContentsObserver {
diff --git a/chrome/browser/ui/search/instant_page.h b/chrome/browser/ui/search/instant_page.h
index b2de2bb..f26e940 100644
--- a/chrome/browser/ui/search/instant_page.h
+++ b/chrome/browser/ui/search/instant_page.h
@@ -52,8 +52,8 @@ class InstantPage : public content::WebContentsObserver,
virtual void InstantSupportDetermined(const content::WebContents* contents,
bool supports_instant) = 0;
- // Called when the underlying RenderView crashed.
- virtual void InstantPageRenderViewGone(
+ // Called when the underlying RenderView's process crashed.
+ virtual void InstantPageRenderProcessGone(
const content::WebContents* contents) = 0;
// Called when the page is about to navigate to |url|.